@@ -4,7 +4,7 @@
 """
 ===============================================================================
 
-    Original code copyright (C) 2009-2018 Rudolf Cardinal (rudolf@pobox.com).
+    Original code copyright (C) 2009-2019 Rudolf Cardinal (rudolf@pobox.com).
 
     This file is part of cardinal_pythonlib.
 
@@ -694,6 +694,16 @@ class BraceStyleAdapter(logging.LoggerAdapter):
         return msg, log_kwargs
 
 
+def get_brace_style_log_with_null_handler(name: str) -> BraceStyleAdapter:
+    """
+    For use by library functions. Returns a log with the specifed name that
+    has a null handler attached, and a :class:`BraceStyleAdapter`.
+    """
+    log = logging.getLogger(name)
+    log.addHandler(logging.NullHandler())
+    return BraceStyleAdapter(log)
+
+
 # =============================================================================
 # Testing
 # =============================================================================
